@@ -7,7 +7,7 @@ use Carp qw/croak/;
 use List::MoreUtils qw/all any uniq/;
 use Set::Crontab;
 
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 
 my @keys = qw/minute hour day month day_of_week/;
 my @ranges = (
@@ -111,7 +111,7 @@ sub match {
     my @lt = localtime($_[0]);
     if ( $self->_contains('minute', $lt[1]) 
       && $self->_contains('hour', $lt[2])
-      && ( $self->_contains('day', $lt[3]) || $self->_contains('day_of_week', $lt[6]) )
+      && ( $self->_contains('day', $lt[3]) && $self->_contains('day_of_week', $lt[6]) )
       && $self->_contains('month', $lt[4]+1) ) {
         return 1;
     }
